/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *
 *   Copyright (C) 2008 by Lukas Appelhans <l.appelhans@gmx.de>
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/ 
#include "kgetapplet.h"
#include "kget_interface.h"

#include <plasma/dataengine.h>

#include <QGraphicsSceneDragDropEvent>
#include <QDropEvent>
#include <QtDBus/QDBusConnectionInterface>
#include <KUrl>

KGetApplet::KGetApplet(QObject *parent, const QVariantList &args)
  : Plasma::Applet(parent, args),
    m_engine(0)
{
    setAcceptDrops(true);
}

KGetApplet::~KGetApplet()
{
}

void KGetApplet::init()
{
    m_engine = dataEngine("kget");
    if (m_engine) {
        m_engine->connectSource("KGet", this, 5000);
    } else {
        kDebug(5001) << "KGet Engine could not be loaded";
    }
}

void KGetApplet::setTransfers(const QVariantMap &transfers)
{
    QList<OrgKdeKgetTransferInterface*> ts;
    QList<OrgKdeKgetTransferInterface*> added;
    QVariantMap::const_iterator it;
    QVariantMap::const_iterator itEnd = transfers.constEnd();
    for (it = transfers.constBegin(); it != itEnd; ++it) {
        const QString &url = it.key();
        OrgKdeKgetTransferInterface* t = 0;
        foreach (OrgKdeKgetTransferInterface* transfer, m_transfers) {
            if (transfer->source().value() == url) {
                t = transfer;
                m_transfers.removeAll(transfer);
                break;
            }
        }
        if (t)
            ts.append(t);
        else {
            OrgKdeKgetTransferInterface* transfer = new OrgKdeKgetTransferInterface("org.kde.kget", 
                                                                                    transfers[url].toString(), QDBusConnection::sessionBus(), this);
            ts.append(transfer);
            added.append(transfer);
        }
    }
    emit transfersRemoved(m_transfers);
    emit transfersAdded(added);
    m_transfers = ts;
}

bool KGetApplet::sceneEventFilter(QGraphicsItem * watched, QEvent * event)
{
    Q_UNUSED(watched);
    switch (event->type())
    {
        case QEvent::GraphicsSceneDrop:
            dropEvent(static_cast<QGraphicsSceneDragDropEvent*>(event));
            return true;
        case QEvent::Drop:
            dropEvent(static_cast<QDropEvent*>(event));
            return true;
        default:
            break;
    }
    return false;
}

void KGetApplet::dropEvent(QGraphicsSceneDragDropEvent * event)
{
    kDebug(5001);    
    
    QStringList urls;
    if (event->mimeData()->hasUrls())
    {
        foreach (const KUrl &url, event->mimeData()->urls())
            urls.append(url.url());
    }
    else
    {
        event->ignore();
        return;
    }
    
    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(KGET_DBUS_SERVICE))
    {
        OrgKdeKgetMainInterface kget_interface(KGET_DBUS_SERVICE, KGET_DBUS_PATH,
                            QDBusConnection::sessionBus());

        kget_interface.showNewTransferDialog(urls);
    }
    else
    {
        QProcess::startDetached("kget", urls);
    }
    event->accept();
}

void KGetApplet::dropEvent(QDropEvent * event)
{
    kDebug(5001);
    
    QStringList urls;
    if (event->mimeData()->hasUrls())
    {
        foreach (const KUrl &url, event->mimeData()->urls())
            urls.append(url.url());
    }
    else
    {
        event->ignore();
        return;
    }
    
    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(KGET_DBUS_SERVICE))
    {
        OrgKdeKgetMainInterface kget_interface(KGET_DBUS_SERVICE, KGET_DBUS_PATH,
                            QDBusConnection::sessionBus());

        kget_interface.showNewTransferDialog(urls);
        event->accept();
    }
    else
    {
        QProcess::startDetached("kget", urls);
    }
    event->accept();
}

#include "kgetapplet.moc"
